All pastes #247949 Raw Edit

Something

public text v1 · immutable
#247949 ·published 2006-11-14 00:38 UTC
rendered paste body
dialog price { 
  title "Price Lookup" 
  size -1 -1 204 142 
  option dbu 
  text "Price lookup By JYANG", 1, 159 8 31 14 
  button "Ok", 2, 169 127 32 12, ok cancel 
  text "Item to look up:", 3, 7 13 40 8 
  edit "", 4, 51 12 76 9, center 
  button "Search", 5, 132 11 21 11 
  list 6, 5 24 194 88, size 
  radio "Lookup Prices", 7, 6 3 50 8 
  radio "Track Prices", 8, 104 3 50 8 
  text "Track Item:", 9, 19 13 28 8 
  button "Track First Item", 10, 6 113 42 12 
  button "Clear Tracking", 11, 51 127 37 12 
  button "Stop Tracking", 12, 6 127 42 12, multi 
  button "List Tracked", 13, 51 113 37 12 
  button "Refresh All", 14, 90 113 38 12 
  button "Settings", 15, 130 113 37 12 
  button "Help", 16, 130 127 37 12 
  button "Clear - Confirm", 17, 90 127 38 12 
} 
dialog pricesettings { 
  title "Price - Settings" 
  size -1 -1 84 123 
  option dbu 
  box "Refresh the Results", 1, 4 8 74 40 
  check "On Startup of the dialog", 2, 7 17 69 10 
  check "Refresh All button", 4, 7 27 64 10, disable 
  button "Ok", 5, 42 107 37 12, ok cancel 
  box "Start the dialog", 6, 4 50 74 22 
  check "On Startup of mIRC", 7, 7 58 64 10 
  box "Start on", 8, 4 74 74 31 
  radio "Lookup Prices", 9, 7 81 50 10, group 
  radio "Track Prices", 10, 7 91 50 10, group 
  check "Selected Track Prices", 3, 7 37 66 10 
} 
on *:start: { 
  if (!$exists(pricetrack.ini)) { 
    writeini pricetrack.ini settings start lookup 
    writeini pricetrack.ini settings startmirc off 
    writeini pricetrack.ini settings startresults off 
  } 
  if ($readini(pricetrack.ini,settings,startmirc) == on) { 
    pricedialog 
  } 
} 
on *:dialog:pricesettings:init:0: { 
  did -c pricesettings 4 
  if ($readini(pricetrack.ini,settings,starttrack) == on) { 
    did -c pricesettings 3 
  } 
  if ($readini(pricetrack.ini,settings,startmirc) == on) { 
    did -c pricesettings 7 
  } 
  if ($readini(pricetrack.ini,settings,start) == lookup) { 
    did -c pricesettings 9 
  } 
  if ($readini(pricetrack.ini,settings,start) == track) { 
    did -c pricesettings 10 
  } 
  if ($readini(pricetrack.ini,settings,startresults) == on) { 
    did -c pricesettings 2 
  } 
} 
on *:dialog:pricesettings:sclick:*: { 
  if ($did == 3) { 
    if ($did(3).state) { 
      writeini pricetrack.ini settings starttrack on 
    } 
    else { writeini pricetrack.ini settings starttrack off } 
  } 
  if ($did == 9) { 
    writeini pricetrack.ini settings start lookup 
  } 
  if ($did == 10) { 
    writeini pricetrack.ini settings start track 
  } 
  if ($did == 7) { 
    if ($did(7).state) { 
      writeini pricetrack.ini settings startmirc on 
    } 
    else { writeini pricetrack.ini settings startmirc off } 
  } 
  if ($did == 2) { 
    if ($did(2).state) { 
      writeini pricetrack.ini settings startresults on 
    } 
    else { writeini pricetrack.ini settings startresults off } 
  } 
} 
on *:dialog:price:sclick:*: { 
  if ($did == 16) { 
    did -b price 6,7,8 
    did -m price 4 
    did -r price 6 
    if ($sock(price.help)) { sockclose price.help } 
    sockopen price.help x.jooldesigns.net 80 
  } 
  if ($did == 15) { 
    dialog -ma pricesettings pricesettings 
  } 
  if ($did == 6) { 
    if (*2P* iswm $did(6).seltext) { 
      did -ra price 4 $replace($gettok($remove($did(6).seltext,[F2P],[P2P],:),1,32),$chr(95),$chr(32)) 
    } 
    elseif (*_* iswm $did(6).seltext) && (Unable != $gettok($did(6,3).seltext,1,32)) && (Searching != $gettok($did(6,3).seltext,1,32)) && (The != $gettok($did(6,3).seltext,1,32)) && ([ != $gettok($did(6,3).seltext,1,32)) { 
      did -ra price 4 $replace($gettok($remove($did(6).seltext,[F2P],[P2P],:),1,32),$chr(95),$chr(32)) 
    } 
  } 
  if ($did == 5) && ($did(7).state) { 
    if ($did(4)) && ($did(4) != No Item Specified) { 
      did -b price 6,7,8 
      if ($sock(price.dialog)) { sockclose price.dialog } 
      set %sent 0 
      set %total 0 
      did -ra price 4 $upper($did(4)) 
      did -m price 4 
      did -r price 6 
      did -a price 6 Searching for the item: $chr(91) $+ $did(4) $+ $chr(93) in the Zybez Price Database. 
      sockopen price.dialog zybez.net 80 
    } 
    else { did -ra price 4 No Item Specified } 
  } 
  if ($did == 5) && ($did(8).state) { 
    if ($did(4)) && ($did(4) != No Item Specified) { 
      did -b price 6,7,8 
      if ($sock(price.dialog)) { sockclose price.dialog } 
      set %sent 0 
      set %total 0 
      did -ra price 4 $upper($did(4)) 
      did -m price 4 
      did -r price 6 
      did -a price 6 Searching for the item: $chr(91) $+ $did(4) $+ $chr(93) in the Zybez Price Database. 
      sockopen price.dialog zybez.net 80 
    } 
    else { did -ra price 4 No Item Specified } 
  } 
  if ($did == 7) { 
    did -ra price 6 You currently selected Price Lookup. 
    did -b price 10,11,12,13,14 
    did -v price 3 
    did -h price 9 
    did -r price 4 
  } 
  if ($did == 8) { 
    did -r price 4 
    did -h price 3 
    did -v price 9 
    did -e price 10,11,12,13,14 
    if ($readini(pricetrack.ini,settings,starttrack) == on) { 
      did -ra price 6 Looking up all the tracked items... 
      did -m price 4 
      var %s = 1 
      while ($readini(pricetrack.ini,list,$+(n,%s))) { 
        if ($readini(pricetrack.ini,list,$+(n,%s)) != None) { 
          did -ra price 4 $replace($gettok($readini(pricetrack.ini,list,$+(n,%s)),1,32),_,$chr(32)) 
          did -b price 6,7,8 
          set %sent 0 
          if ($sock(price.dialog)) { sockclose price.dialog } 
          sockopen price.dialog zybez.net 80 
          break 
          halt 
        } 
        else { inc %s } 
      } 
      if (!$readini(pricetrack.ini,list,$+(n,%s))) { 
        did -a price 6 You are currently not tracking any items. 
        did -n price 4 
      } 
    } 
    else { 
      did -ra price 6 You currently selected Price Tracking. 
    } 
  } 
  if ($did == 10) { 
    if (*2P* iswm $did(price,6,3)) { 
      if ($readini(pricetrack.ini,track,$gettok($remove($did(price,6,3),[F2P],[P2P]),1,58))) { 
        halt 
      } 
      var %s = 1 
      while ($readini(pricetrack.ini,list,$+(n,%s))) { 
        inc %s 
      } 
      writeini pricetrack.ini list $+(n,%s) $remove($did(price,6,3),[F2P],[P2P],:) ( $+ $fulldate $+ ) 
      writeini pricetrack.ini track $remove($did(price,6,3),[F2P],[P2P],:) ( $+ $fulldate $+ ) 
      did -i price 6 1 Started to track: $did(price,6,3) 
    } 
  } 
  if ($did == 11) { 
    did -v price 17 
    did -ra price 6 Click the button Clear-Confirm to delete all the tracked items. 
  } 
  if ($did == 17) { 
    did -h price 17 
    remini pricetrack.ini track 
    remini pricetrack.ini list 
    did -r price 6 
    did -a price 6 All tracked items are deleted. 
  } 
  if ($did == 12) { 
    if (*2P* !iswm $did(price,6,3)) { halt } 
    var %s = 1 
    while ($readini(pricetrack.ini,list,$+(n,%s))) { 
      if ($gettok($remove($did(price,6,3),[F2P],[P2P],:),1,32) == $gettok($readini(pricetrack.ini,list,$+(n,%s)),1,32)) { 
        writeini pricetrack.ini list $+(n,%s) NONE 
        break 
      } 
      else { inc %s } 
    } 
    remini pricetrack.ini track $remove($did(price,6,3),[F2P],[P2P],:) 
  } 
  if ($did == 13) { 
    did -r price 6 
    if ($readini(pricetrack.ini,list,n1)) { 
      did -a price 6 Listing tracked items: 
      var %s = 1 
      while ($readini(pricetrack.ini,list,$+(n,%s))) { 
        if ($readini(pricetrack.ini,list,$+(n,%s)) == None) { inc %s } 
        else { 
          did -a price 6 $readini(pricetrack.ini,list,$+(n,%s)) 
          inc %s 
        } 
      } 
    } 
    else { did -a price 6 You are currently not tracked any items. } 
  } 
  if ($did == 14) { 
    did -ra price 6 Looking up all the tracked items... 
    did -m price 4 
    var %s = 1 
    while ($readini(pricetrack.ini,list,$+(n,%s))) { 
      if ($readini(pricetrack.ini,list,$+(n,%s)) != None) { 
        did -ra price 4 $replace($gettok($readini(pricetrack.ini,list,$+(n,%s)),1,32),_,$chr(32)) 
        did -b price 6,7,8 
        set %sent 0 
        if ($sock(price.dialog)) { sockclose price.dialog } 
        sockopen price.dialog zybez.net 80 
        break 
        halt 
      } 
      else { inc %s } 
    } 
    if (!$readini(pricetrack.ini,list,$+(n,%s))) { 
      did -a price 6 You are currently not tracking any items. 
      did -n price 4 
    } 
  } 
} 
on *:dialog:price:init:0: { 
  did -h price 17 
  if ($readini(pricetrack.ini,settings,start) == track) { 
    did -c price 8 
    did -a price 6 Welcome! 
    did -a price 6 This price script was made by Jyang. 
    did -ra price 6 You currently selected Price Tracking. 
    did -r price 4 
    did -h price 3 
    did -e price 10,11,12,13,14 
    did -v price 9 
  } 
  elseif ($readini(pricetrack.ini,settings,start) == lookup) { 
    did -c price 7 
    did -a price 6 Welcome! 
    did -a price 6 This price script was made by Jyang. 
    did -a price 6 You currently selected Price Lookup. 
    did -b price 10,11,12,13,14 
    did -t price 5 
    did -h price 9 
  } 
  if ($readini(pricetrack.ini,settings,startresults) == on) { 
    did -r price 4 
    did -h price 3 
    did -u price 7 
    did -c price 8 
    did -e price 10,11,12,13,14 
    did -v price 9 
    did -ra price 6 Looking up all the tracked items... 
    did -m price 4 
    var %s = 1 
    while ($readini(pricetrack.ini,list,$+(n,%s))) { 
      if ($readini(pricetrack.ini,list,$+(n,%s)) != None) { 
        did -ra price 4 $replace($gettok($readini(pricetrack.ini,list,$+(n,%s)),1,32),_,$chr(32)) 
        did -b price 6,7,8 
        set %sent 0 
        if ($sock(price.dialog)) { sockclose price.dialog } 
        sockopen price.dialog zybez.net 80 
        halt 
        break 
      } 
      else { inc %s } 
    } 
    if (!$readini(pricetrack.ini,list,$+(n,%s))) { 
      did -a price 6 You are currently not tracking any items. 
      did -n price 4 
    } 
  } 
} 
on *:dialog:price:close:0: { 
  sockclose price.dialog 
} 
on *:sockopen:price.help: { 
  did -r price 6 
  sockwrite -nt $sockname GET /files/47/Price-Readme.txt HTTP/1.1 
  sockwrite -nt $sockname Host: x.jooldesigns.net $+ $crlf $+ $crlf 
} 
on *:sockread:price.help: { 
  if ($sockerr) { did -ra price 6 Error } 
  else { 
    var %price.help 
    sockread %price.help 
    if (%price.read == 1) { 
      did -a price 6 %price.help 
    } 
    if (::start:: == %price.help) { set %price.read 1 | halt } 
  } 
} 
on *:sockclose:price.help: { 
  did -n price 4 
  did -e price 6,7,8 
  unset %price.read 
} 
on *:sockopen:price.dialog: { 
  sockwrite -nt $sockname GET /priceguide.php?search_terms= $+ $replace($did(price,4),$chr(32),$chr(43)) $+ &search_area=1&price_low=&price_high=&member=1&all_prices=1&sortby=name&sort=ASC&ppage=0 HTTP/1.1 
  sockwrite -nt $sockname Host: zybez.net $+ $crlf $+ $crlf 
} 
on *:sockread:price.dialog: { 
  if ($sockerr) { did -a price 6 An error occured while searching for $did(price,4) } 
  else { 
    var %priceread 
    sockread %priceread 
    if (%read == 2) { 
      inc %read 
      var %sockprice $htmlstrip(%priceread) 
      var %send %sockitem $+ : %sockprice 
      if (%sent < 50) { 
        if ($did(price,7).state) || (($did(price,8).state) && (!$readini(pricetrack.ini,track,$replace(%sockitem,$chr(32),_)))) { 
          did -a price 6 $iif(%m,%m,[F2P]) %send 
        } 
        else { 
          did -a price 6 Current Price: 
          did -a price 6 $iif(%m,%m,[F2P]) %send 
          did -a price 6 Previous Price: 
          did -a price 6 %sockitem $readini(pricetrack.ini,n,track,$replace(%sockitem,$Chr(32),_)) 
          var %newprice1 = $remove($gettok(%sockprice,1,32),gp,$chr(44)) 
          var %newprice2 = $remove($gettok(%sockprice,3,32),gp,$chr(44)) 
          var %oldprice1 = $remove($gettok($readini(pricetrack.ini,n,track,$replace(%sockitem,$Chr(32),_)),1,32),gp,$chr(44)) 
          var %oldprice2 = $remove($gettok($readini(pricetrack.ini,n,track,$replace(%sockitem,$Chr(32),_)),3,32),gp,$chr(44)) 
          var %oldtotal = $calc($eval(%oldprice1) + $eval(%oldprice2)) 
          var %newtotal = $calc($eval(%newprice1) + $eval(%newprice2)) 
          if ($eval(%oldtotal) > $eval(%newtotal)) { 
            var %price1 = $comma($calc($eval(%oldprice1 - $eval(%newprice1)))) 
            var %price2 = $comma($calc($eval(%oldprice2 - $eval(%newprice2)))) 
            did -a price 6 The item: $chr(91) $+ %sockitem $+ $chr(93) dropped by $iif(%price1 == %price2,%price1,$iif(%price1 < %price2,%price1 - %price2,%price2 - %price1)) $+ . 
            writeini pricetrack.ini track $replace(%sockitem,$chr(32),_) %sockprice ( $+ $fulldate $+ ) 
          } 
          if ($eval(%oldtotal) < $eval(%newtotal)) { 
            var %price1 = $comma($calc($eval(%newprice1 - $eval(%oldprice1)))) 
            var %price2 = $comma($calc($eval(%newprice2 - $eval(%oldprice2)))) 
            did -a price 6 The item: $chr(91) $+ %sockitem $+ $chr(93) rose by $iif(%price1 == %price2,%price1,$iif(%price1 < %price2,%price1 - %price2,%price2 - %price1)) $+ . 
            writeini pricetrack.ini track $replace(%sockitem,$chr(32),_) %sockprice ( $+ $fulldate $+ ) 
          } 
          if ($eval(%oldtotal) == $eval(%newtotal)) { 
            did -a price 6 The item: $chr(91) $+ %sockitem $+ $chr(93) did not rise or drop. 
          } 
          var %s = 1 
          while ($readini(pricetrack.ini,list,$+(n,%s))) { 
            if ($gettok($replace($did(price,4),$chr(32),_),1,32) == $gettok($readini(pricetrack.ini,list,$+(n,%s)),1,32)) { 
              if ($eval(%oldtotal) != $eval(%newtotal)) { 
                set %change %change $+ $iif(%change,$chr(44),$chr(32)) %sockitem 
                writeini pricetrack.ini list $+(n,%s) $replace($did(price,4),$chr(32),_) %sockprice ( $+ $fulldate $+ ) 
              } 
              break 
            } 
            else { 
              inc %s 
              continue 
            } 
          } 
          if (tracked items isin $did(price,6,1)) { 
            inc %s 
            if ($readini(pricetrack.ini,list,$+(n,%s))) { 
              did -a price 6 ---------------------------------------------------------------------------------------------- 
              did -ra price 4 $replace($gettok($readini(pricetrack.ini,list,$+(n,%s)),1,32),_,$chr(32)) 
              did -b price 6,7,8 
              sockclose $sockname 
              sockopen price.dialog zybez.net 80 
              halt 
            } 
            else { 
              if (%change) { 
                did -i price 6 2 ************************************************************************************** 
                did -i price 6 2 $chr(91) $+ $iif($len(%change) <= 65,%change,Too many items. Look below for the changed items) $+ $chr(93) 
                did -i price 6 2 The items below changed prices: 
                did -i price 6 2 ************************************************************************************** 
              } 
              else { 
                did -i price 6 2 The prices for all the items did not change. 
              } 
              did -a price 6 --- END --- 
              did -n price 4 
              did -e price 6,7,8 
              unset %m 
              unset %sent 
              unset %read 
              unset %sent 
              unset %change 
              unset %total 
              unset %sockitem 
              sockclose $sockname 
              halt 
            } 
          } 
          did -n price 4 
          did -e price 6,7,8 
          unset %m 
          unset %sent 
          unset %read 
          unset %sent 
          unset %total 
          unset %sockitem 
          sockclose $sockname 
        } 
        inc %sent 
      } 
      unset %m 
    } 
    if (%read == 1) { set %sockitem $replace($htmlstrip(%priceread),$chr(32),_) | set %read 2 | inc %total } 
    if ( *<img src="/img/member.gif"* iswm %priceread) { set %read 1 | set %m [P2P] } 
    if (<td class="tablebottom"><!-- Blank --></td> isin %priceread) { set %read 1 } 
    if (*Your search did not* iswm %priceread) { 
      did -a price 6 Unable to find $chr(91) $+ $did(price,4) $+ $chr(93) in the Zybez database. 
    } 
    if (<!-- Search Results: End --> iswm %priceread) { 
      did -i price 6 2 Displayed %sent out of %total $iif(%total iswm 1,item.,items.) 
      did -a price 6 --- END --- 
    } 
  } 
} 
on *:sockclose:price.dialog: { 
  did -n price 4 
  did -e price 6,7,8 
  unset %m 
  unset %sent 
  unset %read 
  unset %sent 
  unset %total 
  unset %sockitem 
} 

alias htmlstrip { var %x,%y = $regsub($1-,/(<[^>]+>)/g,$null,%x) | return %x } 
alias comma { 
  if ($1- isnum) { 
    var %x = 1 
    var %y = $ceil($eval($calc($len($1-) / 3))) 
    while (%x <= %y) { 
      var %comma = $+($chr(44),$right($1-,3),%comma) 
      tokenize 32 $left($1-,-3) 
      inc %x 
    } 
    while ($left(%comma,1) iswm $chr(44)) { var %comma $right(%comma,-1) } 
    return %comma 
  } 
  else { return 0 } 
}